IMallocImpl

Trait IMallocImpl 

pub trait IMallocImpl: IUnknownImpl {
    // Required methods
    unsafe extern "system" fn Alloc(
        this: *mut Self,
        size: usize,
    ) -> *mut void;
    unsafe extern "system" fn Realloc(
        this: *mut Self,
        p: *mut void,
        size: usize,
    ) -> *mut void;
    unsafe extern "system" fn Free(this: *mut Self, p: *mut void);
    unsafe extern "system" fn GetSize(
        this: *mut Self,
        p: *mut void,
    ) -> usize;
    unsafe extern "system" fn DidAlloc(
        this: *mut Self,
        p: *mut void,
    ) -> int;
    unsafe extern "system" fn HeapMinimize(this: *mut Self);
}
Trait implementing methods of interface IMalloc.

To make a struct implementing this trait into a COM object, add a reference to the vtable as the first field of the struct. This reference can be generated using IMallocVtbl::dispatch.

Required Methods

unsafe extern "system" fn Alloc( this: *mut Self, size: usize, ) -> *mut void

unsafe extern "system" fn Realloc( this: *mut Self, p: *mut void, size: usize, ) -> *mut void

unsafe extern "system" fn Free(this: *mut Self, p: *mut void)

unsafe extern "system" fn GetSize( this: *mut Self, p: *mut void, ) -> usize

unsafe extern "system" fn DidAlloc( this: *mut Self, p: *mut void, ) -> int

unsafe extern "system" fn HeapMinimize(this: *mut Self)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors